//#define XERR
#include "random.ih"

unique_ptr<Random> Random::s_random;
